==> advert-1.2.4-sources.jar: com/yodo1ads/adapter/interstitial/AdvertAdapteradmob.java <==
package com.yodo1ads.adapter.interstitial;

import android.app.Activity;
import android.app.Application;
import android.content.Intent;
import android.os.Bundle;

import com.google.ads.mediation.facebook.FacebookAdapter;
import com.google.ads.mediation.tapjoy.TapjoyAdapter;
import com.ironsource.admobadapters.GADIronSourceUtils;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.InterstitialAd;
import com.yodo1.advert.interstitial.AdInterstitialAdapterBase;
import com.yodo1.advert.interstitial.Yodo1InterstitialCallback;
import com.yodo1.advert.interstitial.Yodo1InterstitialReloadCallback;
import com.yodo1ads.plugin.admob.AdConfigAdMob;
import com.yodo1ads.plugin.admob.AdvertCoreAdMob;
import com.yodo1.sdk.kit.YLog;
import com.yodo1.advert.onlineconfig.Yodo1OnlineConfigAgent;

import java.util.ArrayList;

public class AdvertAdapteradmob extends AdInterstitialAdapterBase {

    private Yodo1InterstitialCallback intersititalCallback; //插屏回调
    private Yodo1InterstitialReloadCallback callback;
    private AdRequest adRequest;
    int ads = 0;
    private ArrayList<InterstitialAd> interstitialAds;
    private ArrayList<String> keys;
    public  ArrayList<Boolean> isLoded;

    @Override
    public String getAdvertCode() {
        return AdConfigAdMob.CHANNEL_CODE;
    }


    //    预加载
    @Override
    public void reloadInterstitialAdvert(Activity activity, Yodo1InterstitialReloadCallback callback) {
        this.callback = callback;
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return ;
        }

        // Request a new ad if one isn't already loaded
        //同时预加载四个广告位的广告
        for (int i = 0 ; i < ads ; i++){
            YLog.d("admob  请求第  " + (i+1) + " 个广告位");
            reloadAdvert(interstitialAds.get(i));
        }
    }


    @Override
    public boolean interstitialAdvertIsLoaded(Activity activity) {
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return false;
        }

        return reloadAdvertForAll(interstitialAds);
    }

    @Override
    public void showIntersititalAdvert(Activity activity,final Yodo1InterstitialCallback callback) {
        this.intersititalCallback = callback;
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            callback.onAdError(Yodo1InterstitialCallback.ADVERT_ERROR_LOADED_FAILED, "未成功预加载", getAdvertCode());
            return ;
        }


        // Request a new ad if one isn't already loaded
        //展示指定广告位广告
        int index = 0;
        while (index >= 0 && index < ads){
            YLog.d("admob  展示第  " + (index+1)  + " 个广告位");
            if (isLoaded(interstitialAds.get(index),index)){
                interstitialAds.get(index).show();
                isLoded.add(index,false);
                break;
            } else {
                YLog.d("admob第"+(index+1)+"个广告位广告预加载失败");
                if (index == ads-1){
                    callback.onAdError(Yodo1InterstitialCallback.ADVERT_ERROR_LOADED_FAILED, "未成功预加载", getAdvertCode());
                }

            }

            index ++;
        }

    }
    @Override
    public void validateAdsAdapter(Activity activity) {
        AdvertCoreAdMob.getInstance().validateAdsAdapter(activity);
    }
    @Override
    public void onCreateApplication(Application application) {

    }

    @Override
    public void onCreate(Activity activity) {

        isLoded = new ArrayList();
        keys = new ArrayList();

        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"1"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"2"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"3"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"4"));
        ads = keys.size();

        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return ;
        }
        YLog.d("Admob Keys : " + keys);

        Bundle facebook = new FacebookAdapter.FacebookExtrasBundleBuilder()
                .setNativeAdChoicesIconExpandable(false)
                .build();
        Bundle tapjoy = new TapjoyAdapter.TapjoyExtrasBundleBuilder()
                .setDebug(true)
                .build();

        adRequest = new AdRequest.Builder()
                .addNetworkExtrasBundle(FacebookAdapter.class, facebook)
                .addNetworkExtrasBundle(TapjoyAdapter.class, tapjoy)
//                .addTestDevice("9733E0494C99DCF5BC2947EC969EEB58")  //admob  添加测试设备
                .build();
//        AdSettings.addTestDevice("8637b0a3492b1ff92a53105762cd3701"); //Facebook  添加测试设备


        interstitialAds = new ArrayList<>();
        for ( int i = 0 ; i < ads ; i++){
            YLog.d("admob  初始化第  " + (i+1) + " 广告  key: " + keys.get(i));
            initAdmob(activity,i);

        }




    }

    @Override
    public void onStart(Activity activity) {

    }

    @Override
    public void onResume(Activity activity) {
        GADIronSourceUtils.onActivityResumed(activity);
    }

    @Override
    public void onPause(Activity activity) {
        GADIronSourceUtils.onActivityPaused(activity);
    }

    @Override
    public void onRestart(Activity activity) {

    }

    @Override
    public void onStop(Activity activity) {

    }

    @Override
    public void onDestroy(Activity activity) {

    }

    @Override
    public void onActivityResult(Activity activity, int requestCode, int resultCode, Intent data) {

    }

    @Override
    public void onNewIntent(Activity activity, Intent intent) {

    }

    //预加载指定广告位广告
    public void reloadAdvert(InterstitialAd mInterstitialAd) {
        // Request a new ad if one isn't already loaded
        if (mInterstitialAd != null && !mInterstitialAd.isLoaded()) {
            mInterstitialAd.loadAd(adRequest);
        }
    }

    //判断所有广告位是否有广告加载成功
    public boolean reloadAdvertForAll(ArrayList<InterstitialAd> interstitialAds) {
        // Request a new ad if one isn't already loaded
        for (int i =0 ; i< interstitialAds.size() ;i++){
            if (isLoaded(interstitialAds.get(i),i)){
                YLog.d("admob  第  " + (i+1) + " 广告位有广告" );
                return true;
            }
        }
        return false;
    }

    //指定广告位广告是否加载成功
    public boolean isLoaded(InterstitialAd mInterstitialAd,int i){
//        return mInterstitialAd != null && mInterstitialAd.isLoaded();
        return isLoded.get(i);
    }


    private void initAdmob (Activity activity,final int i){
        isLoded.add(i,false);
        InterstitialAd interstitialAd = new InterstitialAd(activity);
        interstitialAd.setAdUnitId(keys.get(i));
        interstitialAd.setAdListener(new AdListener(){
            @Override
            public void onAdClosed() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_CLOSE, getAdvertCode());
                }
            }

            //            Called when an ad request failed. The error code is usually ERROR_CODE_INTERNAL_ERROR, ERROR_CODE_INVALID_REQUEST, ERROR_CODE_NETWORK_ERROR, or ERROR_CODE_NO_FILL.
            @Override
            public void onAdFailedToLoad(int errorCode) {
                YLog.i("Advert, Admob Interstitial onAdFailedToLoad, adErrorCode = " + errorCode);
                if(callback != null){
                    callback.onResult(Yodo1InterstitialReloadCallback.ADVERT_INTERSTITIAL_RELOAD_FAILED, getAdvertCode());
                }
            }

            //           Called when an ad opens an overlay that covers the screen.
            @Override
            public void onAdOpened() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_DISPLAY, getAdvertCode());
                }
            }

            //            Called when an ad leaves the application  eg： 去往浏览器
            @Override
            public void onAdLeftApplication() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_CLICK, getAdvertCode());
                }
            }

            //            Called when an ad is received.
            @Override
            public void onAdLoaded() {
                YLog.d("Advert, AdMob Interstitial onAdLoaded ... ");
                isLoded.add(i,true);
                if(callback != null){
                    callback.onResult(Yodo1InterstitialReloadCallback.ADVERT_INTERSTITIAL_RELOAD_FINISH, getAdvertCode());
                }
            }
        });


        interstitialAds.add(interstitialAd);
    }
}

==> advert-1.3.8-sources.jar: com/yodo1ads/adapter/interstitial/AdvertAdapteradmob.java <==
package com.yodo1ads.adapter.interstitial;

import android.app.Activity;
import android.app.Application;
import android.content.Intent;
import android.os.Bundle;

import com.google.ads.mediation.facebook.FacebookAdapter;
import com.google.ads.mediation.tapjoy.TapjoyAdapter;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.InterstitialAd;
import com.ironsource.mediationsdk.IronSource;
import com.vungle.mediation.VungleInterstitialAdapter;
import com.yodo1.advert.interstitial.AdInterstitialAdapterBase;
import com.yodo1.advert.interstitial.Yodo1InterstitialCallback;
import com.yodo1.advert.interstitial.Yodo1InterstitialReloadCallback;
import com.yodo1ads.plugin.admob.AdConfigAdMob;
import com.yodo1ads.plugin.admob.AdvertCoreAdMob;
import com.yodo1.sdk.kit.YLog;
import com.yodo1.advert.onlineconfig.Yodo1OnlineConfigAgent;

import java.util.ArrayList;
public class AdvertAdapteradmob extends AdInterstitialAdapterBase {

    private Yodo1InterstitialCallback intersititalCallback; //插屏回调
    private Yodo1InterstitialReloadCallback callback;
    private AdRequest adRequest;
    int ads = 0;
    private ArrayList<InterstitialAd> interstitialAds;
    private ArrayList<String> keys;
    public  ArrayList<Boolean> isLoded;

    @Override
    public String getAdvertCode() {
        return AdConfigAdMob.CHANNEL_CODE;
    }


    //    预加载
    @Override
    public void reloadInterstitialAdvert(Activity activity, Yodo1InterstitialReloadCallback callback) {
        this.callback = callback;
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return ;
        }

        // Request a new ad if one isn't already loaded
        //同时预加载四个广告位的广告
        for (int i = 0 ; i < ads ; i++){
            YLog.i("admob  请求第  " + (i+1) + " 个广告位");
            reloadAdvert(interstitialAds.get(i));
        }
    }


    @Override
    public boolean interstitialAdvertIsLoaded(Activity activity) {
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return false;
        }

        return reloadAdvertForAll(interstitialAds);
    }

    @Override
    public void showIntersititalAdvert(Activity activity,final Yodo1InterstitialCallback callback) {
        this.intersititalCallback = callback;
        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            callback.onAdError(Yodo1InterstitialCallback.ADVERT_ERROR_LOADED_FAILED, "未成功预加载", getAdvertCode());
            return ;
        }


        // Request a new ad if one isn't already loaded
        //展示指定广告位广告
        int index = 0;
        while (index >= 0 && index < ads){
            YLog.i("admob  展示第  " + (index+1)  + " 个广告位");
            if (isLoaded(interstitialAds.get(index),index)){
                interstitialAds.get(index).show();
                isLoded.add(index,false);
                break;
            } else {
                YLog.i("admob第"+(index+1)+"个广告位广告预加载失败");
                if (index == ads-1){
                    callback.onAdError(Yodo1InterstitialCallback.ADVERT_ERROR_LOADED_FAILED, "未成功预加载", getAdvertCode());
                }

            }

            index ++;
        }

    }
    @Override
    public void validateAdsAdapter(Activity activity) {
        AdvertCoreAdMob.getInstance().validateAds(activity);
    }
    @Override
    public void onCreateApplication(Application application) {

    }

    @Override
    public void onCreate(Activity activity) {
        AdvertCoreAdMob.getInstance().initAdMob(activity);
        isLoded = new ArrayList();
        keys = new ArrayList();

        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"1"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"2"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"3"));
        keys.add(Yodo1OnlineConfigAgent.getKeyConfigParam(Yodo1OnlineConfigAgent.AdvertType.Platform_InterstitialAd, AdConfigAdMob.CHANNEL_CODE
                , AdConfigAdMob.KEY_AdMob_INTERSTITIAL_ID+"4"));
        ads = keys.size();

        if (keys == null || keys.size()==0){
            YLog.e("Admob  APPID  is null");
            return ;
        }
        YLog.d("Admob Keys : " + keys);


        Bundle facebook = new FacebookAdapter.FacebookExtrasBundleBuilder()
                .setNativeAdChoicesIconExpandable(false)
                .build();
        Bundle tapjoy = new TapjoyAdapter.TapjoyExtrasBundleBuilder()
                .setDebug(true)
                .build();

//        Collection<String> id =  Vungle.getValidPlacements();
//        String[] placements = (String[])id.toArray();
//        Bundle extras = new VungleExtrasBuilder(placements).build();
//        YLog.d("Admob  Vungle Placement Reference ID : " + placements.toString());
        adRequest = new AdRequest.Builder()
                .addNetworkExtrasBundle(FacebookAdapter.class, facebook)
                .addNetworkExtrasBundle(TapjoyAdapter.class, tapjoy)
                .addNetworkExtrasBundle(VungleInterstitialAdapter.class, null) // Interstitial.
//                .addTestDevice("9733E0494C99DCF5BC2947EC969EEB58")  //admob  添加测试设备
                .build();
//        AdSettings.addTestDevice("8637b0a3492b1ff92a53105762cd3701"); //Facebook  添加测试设备


        interstitialAds = new ArrayList<>();
        for ( int i = 0 ; i < ads ; i++){
            YLog.i("admob  初始化第  " + (i+1) + " 广告  key: " + keys.get(i));
            initAdmob(activity,i);

        }

    }

    @Override
    public void onStart(Activity activity) {

    }

    @Override
    public void onResume(Activity activity) {
        IronSource.onResume(activity);
    }

    @Override
    public void onPause(Activity activity) {
        IronSource.onPause(activity);
    }

    @Override
    public void onRestart(Activity activity) {

    }

    @Override
    public void onStop(Activity activity) {

    }

    @Override
    public void onDestroy(Activity activity) {

    }

    @Override
    public void onActivityResult(Activity activity, int requestCode, int resultCode, Intent data) {

    }

    @Override
    public void onNewIntent(Activity activity, Intent intent) {

    }

    //预加载指定广告位广告
    public void reloadAdvert(InterstitialAd mInterstitialAd) {
        // Request a new ad if one isn't already loaded
        if (mInterstitialAd != null && !mInterstitialAd.isLoaded()) {
            mInterstitialAd.loadAd(adRequest);
        }
    }

    //判断所有广告位是否有广告加载成功
    public boolean reloadAdvertForAll(ArrayList<InterstitialAd> interstitialAds) {
        // Request a new ad if one isn't already loaded
        for (int i =0 ; i< interstitialAds.size() ;i++){
            if (isLoaded(interstitialAds.get(i),i)){
                YLog.i("admob  第  " + (i+1) + " 广告位有广告" );
                return true;
            }
        }
        return false;
    }

    //指定广告位广告是否加载成功
    public boolean isLoaded(InterstitialAd mInterstitialAd,int i){
//        return mInterstitialAd != null && mInterstitialAd.isLoaded();
        return isLoded.get(i);
    }


    private void initAdmob (Activity activity,final int i){
        isLoded.add(i,false);
        InterstitialAd interstitialAd = new InterstitialAd(activity);
        interstitialAd.setAdUnitId(keys.get(i));
        interstitialAd.setAdListener(new AdListener(){
            @Override
            public void onAdClosed() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_CLOSE, getAdvertCode());
                }
            }

            //            Called when an ad request failed. The error code is usually ERROR_CODE_INTERNAL_ERROR, ERROR_CODE_INVALID_REQUEST, ERROR_CODE_NETWORK_ERROR, or ERROR_CODE_NO_FILL.
            @Override
            public void onAdFailedToLoad(int errorCode) {
                YLog.i("Advert, Admob Interstitial onAdFailedToLoad, adErrorCode = " + errorCode);
                if(callback != null){
                    callback.onResult(Yodo1InterstitialReloadCallback.ADVERT_INTERSTITIAL_RELOAD_FAILED, getAdvertCode());
                }
            }

            //           Called when an ad opens an overlay that covers the screen.
            @Override
            public void onAdOpened() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_DISPLAY, getAdvertCode());
                }
            }

            //            Called when an ad leaves the application  eg： 去往浏览器
            @Override
            public void onAdLeftApplication() {
                if(intersititalCallback != null){
                    intersititalCallback.onEvent(Yodo1InterstitialCallback.ADVERT_EVENT_CLICK, getAdvertCode());
                }
            }

            //            Called when an ad is received.
            @Override
            public void onAdLoaded() {
                YLog.i("Advert, AdMob Interstitial onAdLoaded ... ");
                isLoded.add(i,true);
                if(callback != null){
                    callback.onResult(Yodo1InterstitialReloadCallback.ADVERT_INTERSTITIAL_RELOAD_FINISH, getAdvertCode());
                }
            }
        });


        interstitialAds.add(interstitialAd);
    }
}
